/** \addtogroup tue_prv_error_management
 *  @{
 * \file    TueObjFusn_AAU_Codes.h
 * \brief   List of different AAU and Function Codes that are used to map an error entry of the error buffer to the 
 *          corresponding AAU and Function. 
 *
 *
 *
 * <br>=====================================================<br>
 * <b>Copyright 2014 by Tuerme.</b>
 * <br>
 * All rights reserved. Property of Tuerme.<br>
 * Restricted rights to use, duplicate or disclose of this code<br>
 * are granted through contract.
 * <br>=====================================================<br>
 */

#ifndef TUEOBJFUSN_AAU_CODES_H
#define TUEOBJFUSN_AAU_CODES_H


/*****************************/
/* AAU Definitions           */
/*****************************/

#define  TUEOBJFUSN_AAU_FUSION                        (0x01u)
#define  TUEOBJFUSN_AAU_ASSOCIATION                   (0x02u)
#define  TUEOBJFUSN_AAU_COMMON_ARRAY_UTILS            (0x04u)
#define  TUEOBJFUSN_AAU_COMMON_MATRIX                 (0x05u)
#define  TUEOBJFUSN_AAU_DISTANCE_SCORE                (0x06u)
#define  TUEOBJFUSN_AAU_EGOCOORDCOMPENSATION          (0x0Cu)
#define  TUEOBJFUSN_AAU_EGOMOTION                     (0x0Du)
#define  TUEOBJFUSN_AAU_GAINESTIMATION                (0x0Eu)
#define  TUEOBJFUSN_AAU_IDPROVIDER                    (0x0Fu)
#define  TUEOBJFUSN_AAU_LKF                           (0x10u)
#define  TUEOBJFUSN_AAU_LKF_TRACKMANAGEMENT           (0x11u)
#define  TUEOBJFUSN_AAU_MODES_FILTERING               (0x12u)
#define  TUEOBJFUSN_AAU_MOTION_TYPE                   (0x13u)
#define  TUEOBJFUSN_AAU_QUALITY_MANAGEMENT            (0x14u)
#define  TUEOBJFUSN_AAU_OBJECT_SELECTION              (0x15u)
#define  TUEOBJFUSN_AAU_TARGET_PREDICTION             (0x16u)
#define  TUEOBJFUSN_AAU_TRACKMERGE                    (0x17u)
#define  TUEOBJFUSN_AAU_VALIDATION_MANAGEMENT         (0x18u)
#define  TUEOBJFUSN_AAU_DIST_MATRIX                   (0x19u)
#define  TUEOBJFUSN_AAU_KINEMATICS                    (0x1Au)
#define  TUEOBJFUSN_AAU_MULTITRACK_REMOVAL            (0x1Bu)
#define  TUEOBJFUSN_AAU_PARAMETER_INTERFACE           (0x1Cu)
#define  TUEOBJFUSN_AAU_TRACKABLE_LIST_UTILS          (0x1Du)
#define  TUEOBJFUSN_AAU_COORDINATED_TURN              (0x1Eu)


/*********************************************************/
/* TUEOBJFUSN_AAU_COMMON_MATRIX AAU Function Definitions */
/*********************************************************/

#define TUEOBJFUSN_AAU_COMMON_MATRIX_F32MATADD           (0x01u)
#define TUEOBJFUSN_AAU_COMMON_MATRIX_F32MATSUB           (0x02u)
#define TUEOBJFUSN_AAU_COMMON_MATRIX_F32MATMUL           (0x03u)
#define TUEOBJFUSN_AAU_COMMON_MATRIX_F32MATTRANSPOSE     (0x04u)
#define TUEOBJFUSN_AAU_COMMON_MATRIX_F32MATINV           (0x05u)
#define TUEOBJFUSN_AAU_COMMON_MATRIX_F32MATDET           (0x06u)
#define TUEOBJFUSN_AAU_COMMON_MATRIX_F32MATZEROS         (0x07u)
#define TUEOBJFUSN_AAU_COMMON_MATRIX_F32MATEYE           (0x08u)
#define TUEOBJFUSN_AAU_COMMON_MATRIX_F32MATMULVEC        (0x09u)
#define TUEOBJFUSN_AAU_COMMON_MATRIX_F32VECADD           (0x0Au)
#define TUEOBJFUSN_AAU_COMMON_MATRIX_F32VECSUB           (0x0Bu)
#define TUEOBJFUSN_AAU_COMMON_MATRIX_F32VECMULVEC        (0x0Cu)
#define TUEOBJFUSN_AAU_COMMON_MATRIX_F32VECZEROS         (0x0Du)
#define TUEOBJFUSN_AAU_COMMON_MATRIX_F32SYM_MAT_ZEROS    (0x0Eu)
#define TUEOBJFUSN_AAU_COMMON_MATRIX_F32SYM_MAT_TO_MAT   (0x0Fu)
#define TUEOBJFUSN_AAU_COMMON_MATRIX_F32MAT_TO_SYM_MAT   (0x10u)
#define TUEOBJFUSN_AAU_COMMON_MATRIX_F32SYM_MAT_EYE      (0x11u)
#define TUEOBJFUSN_AAU_COMMON_MATRIX_F32MAXEIG           (0x12u)
#define TUEOBJFUSN_AAU_COMMON_MATRIX_F32MATNORM          (0x13u)
#define TUEOBJFUSN_AAU_COMMON_MATRIX_F32MATCONDNB        (0x14u)
#define TUEOBJFUSN_AAU_COMMON_MATRIX_F32MATMULSCAL       (0x15u)
#define TUEOBJFUSN_AAU_COMMON_MATRIX_COPY_MAT            (0x16u)
#define TUEOBJFUSN_AAU_COMMON_MATRIX_COPY_VEC            (0x17u)
#define TUEOBJFUSN_AAU_COMMON_MATRIX_INIT_MAT            (0x18u)
#define TUEOBJFUSN_AAU_COMMON_MATRIX_INIT_VEC            (0x19u)
#define TUEOBJFUSN_AAU_COMMON_MATRIX_INIT_SYM_MAT        (0x1Au)
#define TUEOBJFUSN_AAU_COMMON_MATRIX_ADD_SYM_MAT_PART    (0x1Bu)
#define TUEOBJFUSN_AAU_COMMON_MATRIX_F32VECSUBPART       (0x1Cu)
#define TUEOBJFUSN_AAU_COMMON_MATRIX_EGOCOMP_SYMMAT      (0x1Du)
#define TUEOBJFUSN_AAU_COMMON_MATRIX_PREDICT_SYMMAT      (0x1Eu)
#define TUEOBJFUSN_AAU_COMMON_MATRIX_ROTATE_SYMMAT       (0x1Fu)
#define TUEOBJFUSN_AAU_COMMON_MATRIX_COPY_SYMMAT         (0x20u)
#define TUEOBJFUSN_AAU_COMMON_MATRIX_INV_SYMMAT_3X3      (0x21u)

/**************************************************/
/* TUE_FUSION AUU Function Definitions            */
/**************************************************/

#define  TUEOBJFUSN_AAU_FUSION_PERFORM_FUSION_CYCLE             (0x01u)
#define  TUEOBJFUSN_AAU_FUSION_COUNT_NUMBER_OF_INPUT_LISTS      (0x02u)
#define  TUEOBJFUSN_AAU_FUSION_PERFORM_INPUT_VALIDATION         (0x03u)
#define  TUEOBJFUSN_AAU_FUSION_ANALYZE_INPUT_LISTS              (0x04u)
#define  TUEOBJFUSN_AAU_FUSION_IDENTIFY_UPDATED_LISTS           (0x06u)
#define  TUEOBJFUSN_AAU_FUSION_COMPUTE_INPUT_LIST_ORDERING      (0x07u)
#define  TUEOBJFUSN_AAU_FUSION_UPDATE_EGO_MOTION                (0x08u)
#define  TUEOBJFUSN_AAU_FUSION_PERFORM_TIMER_EVENT              (0x09u)
#define  TUEOBJFUSN_AAU_FUSION_START_CYCLE                      (0x0Au)
#define  TUEOBJFUSN_AAU_FUSION_SENSOR_EVENT                     (0x0Bu)

/**************************************************/
/* TUE_ASSOCIATION AUU Function Definitions       */
/**************************************************/
#define  TUEOBJFUSN_AAU_ASSOCIATION_RUN_ASSOCIATION                           (0x01u)
#define  TUEOBJFUSN_AAU_ASSOCIATION_VERIFY_ASSOCIATION_INPUT                  (0x02u)

/**********************************************************/
/* TUEOBJFUSN_AAU_DISTANCE_SCORE AUU Function Definitions */
/**********************************************************/
#define  TUEOBJFUSN_AAU_DISTANCE_SCORE_COMPUTE_EXTENDED_DIST                  (0x01u)
#define  TUEOBJFUSN_AAU_DISTANCE_SCORE_CALCULATE_DISTANCE                     (0x02u)
#define  TUEOBJFUSN_AAU_DISTANCE_SCORE_SLECT_REDUCED_COV_MAT                  (0x03u)
#define  TUEOBJFUSN_AAU_DISTANCE_SCORE_SLECT_REDUCED_STATE_VEC                (0x04u)
#define  TUEOBJFUSN_AAU_DISTANCE_SCORE_GET_COST_MAP_INDEX                     (0x05u)
#define  TUEOBJFUSN_AAU_DISTANCE_SCORE_DISTANCE_SCORE_TRACK_TO_TRACK          (0x06u)
#define  TUEOBJFUSN_AAU_DISTANCE_SCORE_CALCULATE_GAIN                         (0x07u)

/***********************************************************************/
/* TUEOBJFUSN_AAU_EGO_COORDINATE_COMPENSATION AUU Function Definitions */
/***********************************************************************/
#define TUEOBJFUSN_AAU_EGO_COORDINATE_COMPENSATION_COMPENSATE_TRACKABLE_LIST         (0x01u)
#define TUEOBJFUSN_AAU_EGO_COORDINATE_COMPENSATION_ADAPT_COV_MAT                     (0x02u)
#define TUEOBJFUSN_AAU_EGO_COORDINATE_COMPENSATION_COORD_ROTATION                    (0x03u)
#define TUEOBJFUSN_AAU_EGO_COORDINATE_COMPENSATION_COORD_TRANSLATION                 (0x04u)
#define TUEOBJFUSN_AAU_EGO_COORDINATE_COMPENSATION_ANGLE_ROTATION                    (0x05u)

/*********************************************************/
/* TUEOBJFUSN_AAU_EGO_MOTION AUU Function Definitions    */
/*********************************************************/
#define  TUEOBJFUSN_AAU_EGO_MOTION_ITEM_INIT                                         (0x01u)
#define  TUEOBJFUSN_AAU_EGO_MOTION_HISTORY_INIT                                      (0x02u)
#define  TUEOBJFUSN_AAU_EGO_MOTION_GET_MOTION_HISTORY_INDEX                          (0x03u)
#define  TUEOBJFUSN_AAU_EGO_MOTION_GET_EGO_MOTION_HISTORY                            (0x04u)
#define  TUEOBJFUSN_AAU_EGO_MOTION_ADD_ITEM_TO_HISTORY                               (0x05u)
#define  TUEOBJFUSN_AAU_EGO_MOTION_GET_DELTA_PATH                                    (0x06u)
#define  TUEOBJFUSN_AAU_EGO_MOTION_COPY_EGO_MOTION_ITEM                              (0x07u)
#define  TUEOBJFUSN_AAU_EGO_MOTION_COPY_EGO_MOTION_HISTORY                           (0x08u)

/**********************************************************/
/* TUEOBJFUSN_AAU_CALCULATE_GAIN AUU Function Definitions */
/**********************************************************/
#define TUEOBJFUSN_AAU_GAIN_ESTIMATION_GAIN_ESTIMATION                               (0x01u)
#define TUEOBJFUSN_AAU_GAIN_ESTIMATION_GAIN_UPDATE                                   (0x02u)
#define TUEOBJFUSN_AAU_GAIN_ESTIMATION_GAIN_PREDICTION                               (0x03u)
#define TUEOBJFUSN_AAU_GAIN_ESTIMATION_GAIN_COMPENSATION                             (0x04u)
#define TUEOBJFUSN_AAU_GAIN_ESTIMATION_GAIN_COMPENSATION_INVERSE                     (0x05u)
#define TUEOBJFUSN_AAU_GAIN_ESTIMATION_GAIN_PINCREASE                                (0x06u)
#define TUEOBJFUSN_AAU_GAIN_ESTIMATION_GAIN_LIMITGAIN                                (0x07u)
#define TUEOBJFUSN_AAU_GAIN_ESTIMATION_GAIN_INCREASEP                                (0x08u)
#define TUEOBJFUSN_AAU_GAIN_ESTIMATION_GAIN_RELATIVESTATES                           (0x09u)

/*********************************************************/
/* TUEOBJFUSN_AAU_ID_PROVIDER AUU Function Definitions   */
/*********************************************************/
#define TUEOBJFUSN_AAU_ID_PROVIDER_INIT                                              (0x01u)
#define TUEOBJFUSN_AAU_ID_PROVIDER_GET_NEW_FUSION_ID                                 (0x02u)
#define TUEOBJFUSN_AAU_ID_PROVIDER_RELEASE_FUSION_ID                                 (0x03u)
#define TUEOBJFUSN_AAU_ID_PROVIDER_FINISH_CYCLE                                      (0x04u)       

/**************************************************/
/* TUEOBJFUSN_AAU_LKF AUU Function Definitions    */
/**************************************************/
#define TUEOBJFUSN_AAU_LKF_ADD_NEW_TRKBL                                             (0x01u)
#define TUEOBJFUSN_AAU_LKF_GET_DYNAMIC_MODEL                                         (0x02u)
#define TUEOBJFUSN_AAU_LKF_DO_PREDICT                                                (0x03u)
#define TUEOBJFUSN_AAU_LKF_SET_MEASUREMENT_NOISE_ELEMENT                             (0x04u)
#define TUEOBJFUSN_AAU_LKF_DO_CORRECT                                                (0x05u)
#define TUEOBJFUSN_AAU_LKF_CALCULATE_KR                                              (0x06u)

/****************************************************************/
/* TUEOBJFUSN_AAU_LKF_COORDINATED_TURN AUU Function Definitions */
/****************************************************************/
#define TUEOBJFUSN_AAU_LKF_COORDINATED_TURN_DO_PREDICT                               (0x01u)
#define TUEOBJFUSN_AAU_LKF_COORDINATED_TURN_DO_CORRECT                               (0x02u)

/****************************************************************/
/* TUEOBJFUSN_AAU_LKF_TRACK_MANAGEMENT AUU Function Definitions */
/****************************************************************/
#define TUEOBJFUSN_AAU_LKF_TRACK_MANAGEMENT_INIT                                     (0x01u)
#define TUEOBJFUSN_AAU_LKF_TRACK_MANAGEMENT_START_CYCLE                              (0x02u)   
#define TUEOBJFUSN_AAU_LKF_TRACK_MANAGEMENT_FINALIZE_CYCLE                           (0x03u)
#define TUEOBJFUSN_AAU_LKF_TRACK_MANAGEMENT_DELETE_SENSOR_INFORMATION                (0x04u)
#define TUEOBJFUSN_AAU_LKF_TRACK_MANAGEMENT_PREDICT_INTERNAL_TRKBL                   (0x06u)
#define TUEOBJFUSN_AAU_LKF_TRACK_MANAGEMENT_COMPENSATE_INTERNAL_TRKBL                (0x07u)
#define TUEOBJFUSN_AAU_LKF_TRACK_MANAGEMENT_PREDICT_EXTERNAL_TRKBL                   (0x08u)
#define TUEOBJFUSN_AAU_LKF_TRACK_MANAGEMENT_PREDICT_UPDATE_TRKBL                     (0x09u)
#define TUEOBJFUSN_AAU_LKF_TRACK_MANAGEMENT_SETUP_NEW_LKF_TRKBL                      (0x0Au)
#define TUEOBJFUSN_AAU_LKF_TRACK_MANAGEMENT_CHECK_DYING_TRKBLS                       (0x0Bu)
#define TUEOBJFUSN_AAU_LKF_TRACK_MANAGEMENT_COPY_LKF_TRKBL_TO_OUTPUT_LIST            (0x0Cu)
#define TUEOBJFUSN_AAU_LKF_TRACK_MANAGEMENT_CALCULATE_MOTION_TYPE                    (0x0Du)
#define TUEOBJFUSN_AAU_LKF_TRACK_MANAGEMENT_GET_TRACK_LIST_AGE                       (0x0Eu)
#define TUEOBJFUSN_AAU_LKF_TRACK_MANAGEMENT_RUN_TRACK_MERGE                          (0x0Fu)
#define TUEOBJFUSN_AAU_LKF_TRACK_MANAGEMENT_GET_TRKBLE_LIST                          (0x11u)
#define TUEOBJFUSN_AAU_LKF_TRACK_MANAGEMENT_START_NEW_TRKBL                          (0x12u)
#define TUEOBJFUSN_AAU_LKF_TRACK_MANAGEMENT_UPDATE_AGE                               (0x13u)
#define TUEOBJFUSN_AAU_LKF_TRACK_MANAGEMENT_UPDATE_TRKBLE                            (0x14u)
#define TUEOBJFUSN_AAU_LKF_TRACK_MANAGEMENT_UPDATE_TRKBLE_INFOS                      (0x15u)
#define TUEOBJFUSN_AAU_LKF_TRACK_MANAGEMENT_UPDATE_EXISTENCE_PROBABILITY             (0x16u)
#define TUEOBJFUSN_AAU_LKF_TRACK_MANAGEMENT_SELECT_VIO_TRACKBLES                     (0x17u)
#define TUEOBJFUSN_AAU_LKF_TRACK_MANAGEMENT_UPDATE_COORDINATED_TURN_MODEL            (0x18u)
#define TUEOBJFUSN_AAU_LKF_TRACK_MANAGEMENT_DROP_OBJECTS                             (0x19u)
#define TUEOBJFUSN_AAU_LKF_TRACK_MANAGEMENT_REMOVE_OBSOLETE_OBJECTS                  (0x1Au)
#define TUEOBJFUSN_AAU_LKF_TRACK_MANAGEMENT_ADD_TRKBL                                (0x1Bu)
#define TUEOBJFUSN_AAU_LKF_TRACK_MANAGEMENT_CLEAR_VISION                             (0x1Cu)
#define TUEOBJFUSN_AAU_LKF_TRACK_MANAGEMENT_CLEAR_RADAR                              (0x1Du)
#define TUEOBJFUSN_AAU_LKF_TRACK_MANAGEMENT_SETUP_NEW_LKF_TRKBLE                     (0x1Eu)

/*********************************************************/
/* TUEOBJFUSN_AAU_MOTION_TYPE AUU Function Definitions   */
/*********************************************************/
#define TUEOBJFUSN_AAU_MOTION_TYPE_SET_MOTION_TYPE_TRKBL_LIST                        (0x01u)
#define TUEOBJFUSN_AAU_MOTION_TYPE_SET_MOTION_TYPE_TRKBL                             (0x02u)

/**************************************************************/
/* TUEOBJFUSN_AAU_OBJECT_SELECTION AUU Function Definitions   */
/**************************************************************/
#define TUEOBJFUSN_AAU_OBJECT_SELECTION_VIO_TRACKABLE_SELECTION                      (0x01u)
#define TUEOBJFUSN_AAU_OBJECT_SELECTION_SET_DROPPED_TRACKABLES_BINS                  (0x02u)     
#define TUEOBJFUSN_AAU_OBJECT_SELECTION_SET_TRACKABLE_BIN_POSITION                   (0x03u)
#define TUEOBJFUSN_AAU_OBJECT_SELECTION_CALCULATE_OBJECT_RANGE                       (0x04u)
#define TUEOBJFUSN_AAU_OBJECT_SELECTION_CALCULATE_OBJECT_ANGLE                       (0x05u)

/**************************************************************/
/* TUEOBJFUSN_AAU_QUALITY_MANAGEMENT AUU Function Definitions */
/**************************************************************/
#define TUEOBJFUSN_AAU_QUALITY_MANAGEMENT_TUE_PRV_UPDATE_EXISTENCE_PROBABILITY       (0x01u)
#define TUEOBJFUSN_AAU_QUALITY_MANAGEMENT_TUE_PRV_UPDATE_TRACK_QUALITY               (0x02u)             
#define TUEOBJFUSN_AAU_QUALITY_MANAGEMENT_GET_PROBABILITY_TRUE_POSITIVE              (0x04u)              
#define TUEOBJFUSN_AAU_QUALITY_MANAGEMENT_GET_PROBABILITY_FALSE_POSITIVE             (0x05u)
#define TUEOBJFUSN_AAU_QUALITY_MANAGEMENT_UPDATE_EXISTENCE_PROBABILITY               (0x06u)

/*******************************************************/
/* TUEOBJFUSN_AAU_TRACKMERGE AUU Function Definitions  */
/*******************************************************/
#define TUEOBJFUSN_AAU_TRACKMERGE_MERGE_TRACKS                                       (0x01u)
#define TUEOBJFUSN_AAU_TRACKMERGE_MERGE_TRKBL                                        (0x02u)
#define TUEOBJFUSN_AAU_TRACKMERGE_DISTCAM2RADAR                                      (0x03u)
#define TUEOBJFUSN_AAU_TRACKMERGE_FIND_NON_FUSED_TRACKS                              (0x04u)

/******************************************************************/
/* TUEOBJFUSN_AAU_VALIDATION_MANAGEMENT AUU Function Definitions  */
/******************************************************************/
#define TUEOBJFUSN_AAU_VALIDATION_MANAGEMENT_VALIDATE_TRACKABLE                      (0x01u)
#define TUEOBJFUSN_AAU_VALIDATION_MANAGEMENT_VALIDATE_TRACKABLE_MAP                  (0x02u)
#define TUEOBJFUSN_AAU_VALIDATION_MANAGEMENT_VALIDATE_TRACKABLE_LIST                 (0x03u)
#define TUEOBJFUSN_AAU_VALIDATION_MANAGEMENT_VALIDATE_SENSOR_INPUT                   (0x04u)
#define TUEOBJFUSN_AAU_VALIDATION_MANAGEMENT_VALIDATE_OBJECT_LIST                    (0x05u)

/*******************************************************/
/* TUEOBJFUSN_AAU_KINEMATICS AUU Function Definitions  */
/*******************************************************/
#define TUEOBJFUSN_AAU_KINEMATICS_CHECK_INPUT_VALIDITY                               (0x01u)
#define TUEOBJFUSN_AAU_KINEMATICS_RELATIVE_2_OVER_GROUND                             (0x02u)
#define TUEOBJFUSN_AAU_KINEMATICS_OVER_GROUND_2_RELATIVE                             (0x03u)
#define TUEOBJFUSN_AAU_KINEMATICS_KINEMATICS_RELATIVE_2_OVER_GROUND                  (0x04u)
#define TUEOBJFUSN_AAU_KINEMATICS_KINEMATICS_OVER_GROUND_2_RELATIVE                  (0x05u)

/****************************************************************/
/* TUEOBJFUSN_AAU_PARAMETER_INTERFACE AUU Function Definitions  */
/****************************************************************/
#define TUEOBJFUSN_AAU_PARAMETER_INTERFACE_SET_U32SENSORMODE                         (0x01u)
#define TUEOBJFUSN_AAU_PARAMETER_INTERFACE_SET_F32MATCHGATE                          (0x02u)
#define TUEOBJFUSN_AAU_PARAMETER_INTERFACE_SET_F32PEDESTRIANVARIANCEINXFORQ          (0x03u)
#define TUEOBJFUSN_AAU_PARAMETER_INTERFACE_SET_F32PEDESTRIANVARIANCEINYFORQ          (0x05u)
#define TUEOBJFUSN_AAU_PARAMETER_INTERFACE_SET_F32VEHICLEVARIANCEINXFORQ             (0x06u)
#define TUEOBJFUSN_AAU_PARAMETER_INTERFACE_SET_F32VEHICLEVARIANCEINYFORQ             (0x07u)
#define TUEOBJFUSN_AAU_PARAMETER_INTERFACE_SET_BOUTPUTISOVERGROUND                   (0x08u)
#define TUEOBJFUSN_AAU_PARAMETER_INTERFACE_SET_F32EXTENDEDSCOREDIFFERENTID           (0x09u)
#define TUEOBJFUSN_AAU_PARAMETER_INTERFACE_SET_BUSETRACKMERGE                        (0x0Au)
#define TUEOBJFUSN_AAU_PARAMETER_INTERFACE_SET_BUSECOASTING                          (0x0Bu)
#define TUEOBJFUSN_AAU_PARAMETER_INTERFACE_SET_U32COASTEDSENSOR                      (0x0Cu)
#define TUEOBJFUSN_AAU_PARAMETER_INTERFACE_SET_F32ADDITIONALQONDIAGONAL              (0x0Du)
#define TUEOBJFUSN_AAU_PARAMETER_INTERFACE_SET_BUSEMPFNUMOBJECTS                     (0x0Eu)
#define TUEOBJFUSN_AAU_PARAMETER_INTERFACE_SET_F32VARIANCEINHEADINGFORQ              (0x0Fu)

/*****************************************************************/
/* TUEOBJFUSN_AAU_TRACKABLE_LIST_UTILS AUU Function Definitions  */
/*****************************************************************/
#define TUEOBJFUSN_AAU_TRACKABLE_LIST_UTILS_SET_SENSOR_INFOS                         (0x01u)
#define TUEOBJFUSN_AAU_TRACKABLE_LIST_UTILS_TRACKABLE_INIT                           (0x03u)
#define TUEOBJFUSN_AAU_TRACKABLE_LIST_UTILS_TRACKABLE_LIST_INIT                      (0x04u)
#define TUEOBJFUSN_AAU_TRACKABLE_LIST_UTILS_COPY_TRACKABLE                           (0x05u)
#define TUEOBJFUSN_AAU_TRACKABLE_LIST_UTILS_INIT_OBJECT_LIST                         (0x06u)


/**********************************************************************/
/* TUEOBJFUSN_AAU_MODES_FILTERING AUU Function Definitions            */
/**********************************************************************/
#define TUEOBJFUSN_AAU_MODES_FILTERING_MEAS_TO_LKF_UPDATE                            (0x01u)
#define TUEOBJFUSN_AAU_MODES_FILTERING_PREDICT_OBJECT_LIST                           (0x02u)

#endif /** TUEOBJFUSN_AAU_CODES_H */
